[![Python build package](https://github.com/colav/UkuPacha/actions/workflows/python-package.yml/badge.svg)](https://github.com/colav/UkuPacha/actions/workflows/python-package.yml)
<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# UkuPacha  
SQL 2 JSON /  Inca - place between the hell and the earth

# Description
Package to perform relations in a Oracle SQL engine and given the schema in a dictionary, allows to produce a json with the results.

# Installation

## Package
`pip install ukupacha`

# Usage
TODO

# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/



